@@ -39,14 +39,14 @@ test_that("A mixed MNL model converges and creates the output", {
     U_B = ASC_B_RND + @B_price * $price_B / 1000 + @B_timeB * $time_B / 60;
   "
   
-  model_spec <- mixl::specify_model(mnl_test, Train, disable_multicore=T)
+  model_spec <- mixl::specify_model(mnl_test, Train)
   
   #only take starting values that are needed
   est <- stats::setNames(c(0,0,0,0,0,0), c("B_price", "B_time", "B_timeB", "B_change", "ASC_B","SIGMA_B"))
   
   availabilities <- mixl::generate_default_availabilities(Train, model_spec$num_utility_functions)
   
-  model <- mixl::estimate(model_spec, est, Train, availabilities = availabilities, nDraws = 20)
+  system.time(model <- mixl::estimate(model_spec, est, Train, availabilities = availabilities, nDraws = 100, num_threads=1))
   
   expect_equal(model$code, 0)
   expect_length(model$estimate, 6)
